import { Component } from "@angular/core";
import { Platform, NavController } from "ionic-angular";
import { GoogleLocationApiService } from '@justbe-angular/jb-google-location-api';
import { GeoLocationModel } from '@justbe-typescript-models/jb-location';
import { LoadingService } from "@justbe-ionic-angular/jb-loading";
import { PouchService } from "@justbe-angular/jb-pouch";
import { ArraySortClass } from '@justbe-utilities/array-sort';
import { StoreService } from "@justbe-angular/jb-store";
var HTML_TMPL_GETTER = " \n    <ion-header>\n        <ion-navbar>\n            <input class=\"my-input\" type=\"text\" placeholder=\"Enter Location\" [(ngModel)]=\"searchText\" (ngModelChange)=\"inputChanged($event)\" />    \n            <ion-buttons end>\n                <button ion-button icon-only *ngIf=\"spinner\">\n                    <ion-spinner icon=\"ripple\" class=\"spinner-assertive\"></ion-spinner>\n                </button>    \n                <button ion-button icon-only *ngIf=\"searchText?.length>0\" (click)=\"clearSearchBox()\">\n                    <ion-icon name=\"close\" ></ion-icon>\n                </button>\n                <button ion-button icon-only *ngIf=\"!searchText || searchText?.length===0\">\n                    <ion-icon name=\"search\" >\n                    </ion-icon>\n                </button>\n            </ion-buttons>\n        </ion-navbar>\n    </ion-header>\n    <ion-content>\n        <ion-grid no-padding>\n            <ion-list-header>\n                Search results\n            </ion-list-header>\n            <ion-list>\n                <ion-item *ngFor=\"let pred of predictions\" (click)=\"onSearchResultLocationSelect(pred)\">\n                    <ion-icon name=\"pin\" item-start></ion-icon>\n                    <h2>{{pred?.structured_formatting?.main_text}}</h2>\n                    <p text-wrap>{{pred?.structured_formatting?.secondary_text}}</p>\n                </ion-item>\n                <ion-item *ngIf=\"!predictions || predictions && predictions.length===0\">\n                    <ion-icon name=\"pin\" item-start></ion-icon>\n                    <h2>Search location</h2>\n                    <p text-wrap>start typing in the above text box and select location of your choice.</p>\n                </ion-item>\n            </ion-list>\n        </ion-grid>\n        <ion-grid no-padding>\n            <ion-list-header>\n                Use current location\n            </ion-list-header>\n            <ion-list>\n                <ion-item (click)=\"onCurrentLocationSelect(nearByLocations[1])\">\n                    <ion-icon name=\"locate\" item-start></ion-icon>\n                    <h2>Your current location</h2>\n                    <p *ngIf=\"nearByLocations && nearByLocations.length>0\" text-wrap>\n                    {{nearByLocations[1].formatted_address}}\n                    </p>\n                </ion-item>\n            </ion-list>\n        </ion-grid>\n        <ion-grid no-padding>\n            <ion-list>\n                <ion-list-header>\n                    Recent locations\n                </ion-list-header>\n                <ion-item *ngFor=\"let rl of recentLocations;let i=index\" (click)=\"onRecentLocationSelect(rl)\">\n                    <ion-icon name=\"time\" item-start></ion-icon>\n                    <p text-wrap>{{rl?.formatted_address}}</p>\n                </ion-item>\n                <ion-item *ngIf=\"!recentLocations || recentLocations && recentLocations.length===0\">\n                    <ion-icon name=\"time\" item-start></ion-icon>\n                    <h2>Recently searched locations</h2>\n                    <p text-wrap>Location you recently searched will appear here.</p>\n                </ion-item>\n            </ion-list>\n        </ion-grid>\n    </ion-content>\n\n";
var CSS_STYLES = "\n.my-input{\n    width: 100%;\n    background: transparent;\n    border: none;\n    color: white;\n    margin-left: 10px;\n}\n::-webkit-input-placeholder { /* Chrome */\n    color: aliceblue;\n  }\n  :-ms-input-placeholder { /* IE 10+ */\n    color: aliceblue;\n  }\n  ::-moz-placeholder { /* Firefox 19+ */\n    color: aliceblue;\n    opacity: 1;\n  }\n  :-moz-placeholder { /* Firefox 4 - 18 */\n    color: aliceblue;\n    opacity: 1;\n  }\n";
var LocationPickerPage = (function () {
    function LocationPickerPage(plt, googleLocationApiService, loading, pouchService, storeService, navCtrl) {
        this.plt = plt;
        this.googleLocationApiService = googleLocationApiService;
        this.loading = loading;
        this.pouchService = pouchService;
        this.storeService = storeService;
        this.navCtrl = navCtrl;
        this.getGeocodes();
        this.setRecentLocations();
    }
    ;
    LocationPickerPage.prototype.setRecentLocations = function () {
        var _this = this;
        this.pouchService.getAllDocuments('justbe-recent-locations', { include_docs: true }).subscribe(function (res) {
            _this.recentLocations = res;
            _this.recentLocations = ArraySortClass.sort(_this.recentLocations, 'cO', 'desc');
            _this.recentLocations.splice(3, _this.recentLocations.length - 1);
        });
    };
    LocationPickerPage.prototype.getGeocodes = function () {
        if (this.plt.is('core') || this.plt.is('mobileweb')) {
            this.getBrowserGeocodes();
        }
        else {
            this.getNativeGeocodes();
        }
    };
    LocationPickerPage.prototype.getBrowserGeocodes = function () {
        if (navigator.geolocation) {
            var that_1 = this;
            navigator.geolocation.getCurrentPosition(function (position) {
                that_1.lat = position.coords.latitude;
                that_1.lng = position.coords.longitude;
                that_1.setNearbyLocations(position.coords.latitude, position.coords.longitude, position.coords.accuracy);
            }, function error(msg) {
                // observer.error({ key: 1111, msg: 'unable to get geocode from browser' })
            });
        }
    };
    LocationPickerPage.prototype.getNativeGeocodes = function () {
        console.log('native not implemented yet fallback to browser');
        this.getBrowserGeocodes();
    };
    LocationPickerPage.prototype.setNearbyLocations = function (lat, lng, accuracy) {
        var _this = this;
        this.googleLocationApiService.reverseGeocode(lat, lng).subscribe(function (res) {
            if (res.status === 'OK') {
                _this.nearByLocations = res.results;
            }
        });
    };
    LocationPickerPage.prototype.inputChanged = function (searchText) {
        var _this = this;
        if (searchText.length > 1) {
            this.spinner = true;
            this.googleLocationApiService.searchPlaces(searchText, this.lat, this.lng).subscribe(function (res) {
                if (res.status === 'OK') {
                    _this.predictions = res.predictions;
                }
                _this.spinner = false;
            });
        }
        else {
            this.predictions = new Array();
        }
    };
    LocationPickerPage.prototype.onSearchResultLocationSelect = function (location) {
        var _this = this;
        this.loading.show({
            id: 'gpa',
            content: 'Please wait'
        });
        this.googleLocationApiService.geocode(location.description).subscribe(function (res) {
            if (res.status === 'OK') {
                var selectedLocation = res.results[0];
                _this.setLocationToPouch(selectedLocation);
                selectedLocation.formatted_address = location.description;
                var json = _this.getJson(selectedLocation);
                _this.storeService.updateSubstore('jlp:onLocationSelect', json);
                _this.navCtrl.pop();
            }
            _this.loading.hide('gpa');
        });
    };
    LocationPickerPage.prototype.onCurrentLocationSelect = function (location) {
        this.setLocationToPouch(location);
        var json = this.getJson(location);
        this.storeService.updateSubstore('jlp:onLocationSelect', json);
        this.navCtrl.pop();
    };
    LocationPickerPage.prototype.onRecentLocationSelect = function (location) {
        var json = this.getJson(location);
        this.storeService.updateSubstore('jlp:onLocationSelect', json);
        this.navCtrl.pop();
    };
    LocationPickerPage.prototype.clearSearchBox = function () {
        this.searchText = '';
        this.predictions = new Array();
    };
    LocationPickerPage.prototype.getJson = function (location) {
        var jbLocation = GeoLocationModel.build({
            locationText: location.formatted_address,
            geoPoint: {
                latitude: location.geometry.location.lat,
                longitude: location.geometry.location.lng
            }
        });
        return jbLocation;
    };
    LocationPickerPage.prototype.setLocationToPouch = function (json) {
        json["id"] = 'loc' + json.geometry.location.lat + json.geometry.location.lng;
        json["cO"] = new Date().getTime();
        this.pouchService.upsertDocument('justbe-recent-locations', json).subscribe(function (res) {
            console.log('location set');
        });
    };
    LocationPickerPage.decorators = [
        { type: Component, args: [{
                    selector: 'location-picker-page',
                    template: HTML_TMPL_GETTER,
                    styles: [CSS_STYLES]
                },] },
    ];
    /** @nocollapse */
    LocationPickerPage.ctorParameters = function () { return [
        { type: Platform, },
        { type: GoogleLocationApiService, },
        { type: LoadingService, },
        { type: PouchService, },
        { type: StoreService, },
        { type: NavController, },
    ]; };
    return LocationPickerPage;
}());
export { LocationPickerPage };
//# sourceMappingURL=location-picker.page.js.map